@@ -12,7 +12,7 @@ test_that('tpi_selector matches published example.', {
 
 
 
-  # Tests at dose 1
+  # Tests at dose 1 ----
 
   # Three patients treated
   fit <- model %>% fit('1NNN')
@@ -23,6 +23,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNT')
   expect_equal(recommended_dose(fit), 1)
@@ -32,6 +33,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NTT')
   expect_equal(recommended_dose(fit), 1)
@@ -41,6 +43,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -50,6 +53,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   # Six patients treated
   fit <- model %>% fit('1NNN 1NNN')
@@ -60,6 +64,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNT')
   expect_equal(recommended_dose(fit), 1)
@@ -69,6 +74,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NTT')
   expect_equal(recommended_dose(fit), 1)
@@ -78,6 +84,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -87,6 +94,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -96,6 +104,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -105,6 +114,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -114,6 +124,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   # Nine patients treated
   fit <- model %>% fit('1NNN 1NNN 1NNN')
@@ -124,6 +135,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NNT')
   expect_equal(recommended_dose(fit), 2)
@@ -133,6 +145,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NTT')
   expect_equal(recommended_dose(fit), 1)
@@ -142,6 +155,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -151,6 +165,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNT 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -160,6 +175,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NTT 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -169,6 +185,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -178,6 +195,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -187,6 +205,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -196,6 +215,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1TTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -205,6 +225,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   # Twelve patients treated
   fit <- model %>% fit('1NNN 1NNN 1NNN 1NNN')
@@ -215,6 +236,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NNN 1NNT')
   expect_equal(recommended_dose(fit), 2)
@@ -224,6 +246,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NNN 1NTT')
   expect_equal(recommended_dose(fit), 2)
@@ -233,6 +256,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NNN 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -242,6 +266,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NNT 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -251,6 +276,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1NTT 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -260,6 +286,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNN 1TTT 1TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -269,6 +296,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NNT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -278,6 +306,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1NTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -287,6 +316,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNN 1TTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -296,6 +326,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NNT 1TTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -305,6 +336,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1NTT 1TTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -314,6 +346,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('1TTT 1TTT 1TTT 1TTT')
   expect_true(is.na(recommended_dose(fit)))
@@ -323,10 +356,11 @@ test_that('tpi_selector matches published example.', {
     "The model advocates stopping and recommending no dose."
   )
   expect_equal(dose_admissible(fit), rep(FALSE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
 
 
-  # Tests at dose 2
+  # Tests at dose 2 ----
 
   # Three patients treated
   fit <- model %>% fit('2NNN')
@@ -337,6 +371,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNT')
   expect_equal(recommended_dose(fit), 2)
@@ -346,6 +381,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NTT')
   expect_equal(recommended_dose(fit), 1)
@@ -355,6 +391,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -364,6 +401,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Six patients treated
   fit <- model %>% fit('2NNN 2NNN')
@@ -374,6 +412,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNT')
   expect_equal(recommended_dose(fit), 2)
@@ -383,6 +422,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NTT')
   expect_equal(recommended_dose(fit), 2)
@@ -392,6 +432,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -401,6 +442,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -410,6 +452,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -419,6 +462,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -428,6 +472,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Nine patients treated
   fit <- model %>% fit('2NNN 2NNN 2NNN')
@@ -438,6 +483,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NNT')
   expect_equal(recommended_dose(fit), 3)
@@ -447,6 +493,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NTT')
   expect_equal(recommended_dose(fit), 2)
@@ -456,6 +503,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2TTT')
   expect_equal(recommended_dose(fit), 2)
@@ -465,6 +513,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNT 2TTT')
   expect_equal(recommended_dose(fit), 2)
@@ -474,6 +523,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -483,6 +533,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -492,6 +543,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -501,6 +553,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -510,6 +563,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2TTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -519,6 +573,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Twelve patients treated
   fit <- model %>% fit('2NNN 2NNN 2NNN 2NNN')
@@ -529,6 +584,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NNN 2NNT')
   expect_equal(recommended_dose(fit), 3)
@@ -538,6 +594,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NNN 2NTT')
   expect_equal(recommended_dose(fit), 3)
@@ -547,6 +604,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 3."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NNN 2TTT')
   expect_equal(recommended_dose(fit), 2)
@@ -556,6 +614,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NNT 2TTT')
   expect_equal(recommended_dose(fit), 2)
@@ -565,6 +624,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2NTT 2TTT')
   expect_equal(recommended_dose(fit), 2)
@@ -574,6 +634,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 2."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNN 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -583,6 +644,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NNT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -592,6 +654,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2NTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -601,6 +664,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNN 2TTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -610,6 +674,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NNT 2TTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -619,6 +684,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2NTT 2TTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -628,6 +694,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('2TTT 2TTT 2TTT 2TTT')
   expect_equal(recommended_dose(fit), 1)
@@ -637,10 +704,11 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 1."
   )
   expect_equal(dose_admissible(fit), c(TRUE, FALSE, FALSE, FALSE, FALSE))
+  check_dose_selector_consistency(fit)
 
 
 
-  # Tests at top dose (i.e. escalation impossible)
+  # Tests at top dose (i.e. escalation impossible) ----
 
   # Three patients treated
   fit <- model %>% fit('5NNN')
@@ -651,6 +719,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNT')
   expect_equal(recommended_dose(fit), 5)
@@ -660,6 +729,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NTT')
   expect_equal(recommended_dose(fit), 4)
@@ -669,6 +739,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -678,6 +749,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Six patients treated
   fit <- model %>% fit('5NNN 5NNN')
@@ -688,6 +760,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNT')
   expect_equal(recommended_dose(fit), 5)
@@ -697,6 +770,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NTT')
   expect_equal(recommended_dose(fit), 5)
@@ -706,6 +780,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -715,6 +790,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -724,6 +800,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -733,6 +810,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -742,6 +820,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Nine patients treated
   fit <- model %>% fit('5NNN 5NNN 5NNN')
@@ -752,6 +831,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NNT')
   expect_equal(recommended_dose(fit), 5)
@@ -761,6 +841,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NTT')
   expect_equal(recommended_dose(fit), 5)
@@ -770,6 +851,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5TTT')
   expect_equal(recommended_dose(fit), 5)
@@ -779,6 +861,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNT 5TTT')
   expect_equal(recommended_dose(fit), 5)
@@ -788,6 +871,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -797,6 +881,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -806,6 +891,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -815,6 +901,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -824,6 +911,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5TTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -833,6 +921,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   # Twelve patients treated
   fit <- model %>% fit('5NNN 5NNN 5NNN 5NNN')
@@ -843,6 +932,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NNN 5NNT')
   expect_equal(recommended_dose(fit), 5)
@@ -852,6 +942,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NNN 5NTT')
   expect_equal(recommended_dose(fit), 5)
@@ -861,6 +952,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NNN 5TTT')
   expect_equal(recommended_dose(fit), 5)
@@ -870,6 +962,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NNT 5TTT')
   expect_equal(recommended_dose(fit), 5)
@@ -879,6 +972,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5NTT 5TTT')
   expect_equal(recommended_dose(fit), 5)
@@ -888,6 +982,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 5."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNN 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -897,6 +992,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), rep(TRUE, num_doses(fit)))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NNT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -906,6 +1002,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5NTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -915,6 +1012,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNN 5TTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -924,6 +1022,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NNT 5TTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -933,6 +1032,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5NTT 5TTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -942,6 +1042,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
   fit <- model %>% fit('5TTT 5TTT 5TTT 5TTT')
   expect_equal(recommended_dose(fit), 4)
@@ -951,6 +1052,7 @@ test_that('tpi_selector matches published example.', {
     "The model advocates continuing at dose 4."
   )
   expect_equal(dose_admissible(fit), c(TRUE, TRUE, TRUE, TRUE, FALSE))
+  check_dose_selector_consistency(fit)
 
 })
 
